==> rocm-clr-6.4.3.tar.gz: clr-rocm-6.4.3/opencl/tests/ocltst/module/gl/TestList.cpp <==
/* Copyright (c) 2010 - 2021 Advanced Micro Devices, Inc.

 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
 to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in
 all copies or substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 THE SOFTWARE. */

#include "OCLTestListImp.h"

//
// Includes for tests
//
#include "OCLGLBuffer.h"
#include "OCLGLBufferMultipleQueues.h"
#include "OCLGLDepthBuffer.h"
#include "OCLGLDepthTex.h"
#include "OCLGLFenceSync.h"
#include "OCLGLMsaaTexture.h"
#include "OCLGLMultiContext.h"
#include "OCLGLTexture.h"
#include "OCLGLPerfSepia.h"

//
//  Helper macro for adding tests
//
template <typename T>
static void* dictionary_CreateTestFunc(void) {
  return new T();
}

#define TEST(name) \
  { #name, &dictionary_CreateTestFunc < name> }

TestEntry TestList[] = {
    TEST(OCLGLBuffer),    TEST(OCLGLBufferMultipleQueues),
    TEST(OCLGLTexture),   TEST(OCLGLMultiContext),
    TEST(OCLGLFenceSync), TEST(OCLGLDepthTex), TEST(OCLGLPerfSepia),
};

unsigned int TestListCount = sizeof(TestList) / sizeof(TestList[0]);
unsigned int TestLibVersion = 0;
const char* TestLibName = "oclgl";

==> rocm-clr-7.1.0.tar.gz: clr-rocm-7.1.0/opencl/tests/ocltst/module/gl/TestList.cpp <==
/* Copyright (c) 2010 - 2021 Advanced Micro Devices, Inc.

 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
 to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in
 all copies or substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 THE SOFTWARE. */

#include "OCLTestListImp.h"

//
// Includes for tests
//
#include "OCLGLBuffer.h"
#include "OCLGLBufferMultipleQueues.h"
#include "OCLGLDepthBuffer.h"
#include "OCLGLDepthTex.h"
#include "OCLGLFenceSync.h"
#include "OCLGLMsaaTexture.h"
#include "OCLGLMultiContext.h"
#include "OCLGLTexture.h"
#include "OCLGLPerfSepia.h"

//
//  Helper macro for adding tests
//
template <typename T> static void* dictionary_CreateTestFunc(void) { return new T(); }

#define TEST(name) {#name, &dictionary_CreateTestFunc<name>}

TestEntry TestList[] = {
    TEST(OCLGLBuffer),    TEST(OCLGLBufferMultipleQueues),
    TEST(OCLGLTexture),   TEST(OCLGLMultiContext),
    TEST(OCLGLFenceSync), TEST(OCLGLDepthTex),
    TEST(OCLGLPerfSepia),
};

unsigned int TestListCount = sizeof(TestList) / sizeof(TestList[0]);
unsigned int TestLibVersion = 0;
const char* TestLibName = "oclgl";
